@@ -1,7 +1,5 @@
 use std::str::FromStr;
 
-use clap::arg_enum;
-
 use crate::error::FatalError;
 
 #[derive(Clone, Debug)]
@@ -16,29 +14,35 @@ impl TargetVersion {
         current: &semver::Version,
         metadata: Option<&str>,
     ) -> Result<Option<Version>, FatalError> {
-        match self {
+        let bumped = match self {
             TargetVersion::Relative(bump_level) => {
                 let mut potential_version = current.to_owned();
                 if bump_level.bump_version(&mut potential_version, metadata)? {
                     let full_version = potential_version;
-                    Ok(Some(Version::from(full_version)))
+                    let version = Version::from(full_version);
+                    Some(version)
                 } else {
-                    Ok(None)
+                    None
                 }
             }
             TargetVersion::Absolute(version) => {
-                if current < version {
-                    let full_version = version.to_owned();
-                    Ok(Some(Version::from(full_version)))
-                } else if current == version {
-                    Ok(None)
+                let mut full_version = version.to_owned();
+                if full_version.build.is_empty() {
+                    if let Some(metadata) = metadata {
+                        full_version.build = semver::BuildMetadata::new(metadata)?;
+                    } else {
+                        full_version.build = current.build.clone();
+                    }
+                }
+                let version = Version::from(full_version);
+                if version.bare_version != Version::from(current.clone()).bare_version {
+                    Some(version)
                 } else {
-                    Err(crate::error::FatalError::UnsupportedVersionReq(
-                        "Cannot release version smaller than current one".to_owned(),
-                    ))
+                    None
                 }
             }
-        }
+        };
+        Ok(bumped)
     }
 }
 
@@ -102,16 +106,41 @@ impl From<semver::Version> for Version {
     }
 }
 
-arg_enum! {
-    #[derive(Debug, Clone, Copy)]
-    pub enum BumpLevel {
-        Major,
-        Minor,
-        Patch,
-        Rc,
-        Beta,
-        Alpha,
-        Release,
+#[derive(Debug, Clone, Copy, clap::ArgEnum)]
+#[clap(rename_all = "kebab-case")]
+pub enum BumpLevel {
+    Major,
+    Minor,
+    Patch,
+    Rc,
+    Beta,
+    Alpha,
+    Release,
+}
+
+impl std::fmt::Display for BumpLevel {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        use clap::ArgEnum;
+
+        self.to_possible_value()
+            .expect("no values are skipped")
+            .get_name()
+            .fmt(f)
+    }
+}
+
+impl std::str::FromStr for BumpLevel {
+    type Err = String;
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        use clap::ArgEnum;
+
+        for variant in Self::value_variants() {
+            if variant.to_possible_value().unwrap().matches(s, false) {
+                return Ok(*variant);
+            }
+        }
+        Err(format!("Invalid variant: {}", s))
     }
 }
 
